# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['pydui', 'pydui.core', 'pydui.layout', 'pydui.widgets']

package_data = \
{'': ['*']}

install_requires = \
['gobject>=0.1.0,<0.2.0', 'pycairo>=1.21.0,<2.0.0', 'pygobject>=3.42.2,<4.0.0']

entry_points = \
{'console_scripts': ['demo = src.example.demo:main']}

setup_kwargs = {
    'name': 'pydui-gtk',
    'version': '0.1.0',
    'description': 'Wrap PyGObject into a DuiLib-style UI library',
    'long_description': '# PyDui Introduction\n\n**PyDui base on GTK-3, PyGObject**\n\nEven though there is GTK/Glade can quickly and efficiently build a powerful UI Application. But the Glade is not easy enough to learn. Sometimes, we need another solution for rapidly building a simple app. I think, on the windows platform, DuiLib is an option because it\'s easy to learn.\n\n\n\n**Why not just wrap the DuiLib API ?** \n\nThis is a good question because DuiLib only works on windows. And the author work on mac. So, this is not for cross-platform purposes, just personal reasons.\n\n\n\n\n\n# Install\n\n> PyDui require python >= 3.9 \n>\n> Even though it\'s easy to downgrade the python version, personal reasons, the author DO NOT WANT TO KEEP ALL THE VERSION WORK!\n\n```shell\npip install pydui\n```\n\n\n\n\n\n# Code Example\n\n```python\nimport pydui\nfrom pydui import *\n\n\nclass DemoWindowHandler(PyDuiWindowHandler):\n    def __init__(self, window: PyDuiWindow):\n        super().__init__(window=window)\n\n    def on_window_show(self):\n        print(f"on_window_show")\n        window = self.window()\n        widget = window.get_widget(widget_id="button")\n\n        def handle_click(object):\n            print("You clicked!", object)\n\n        widget.connect("clicked", handle_click)\n\n    def on_window_destroy(self):\n        print(f"on_window_destroy")\n        PyDuiApplication.main_quit()\n\n\ndef main():\n    print(f"start pydui version: {pydui.__version__}")\n\n    window = PyDuiBuilder.build_window(\n        path="res/main.xml",\n        handler=DemoWindowHandler,\n    )\n    window.show()\n\n    PyDuiApplication.main_run()\n\n\nif __name__ == "__main__":\n    main()\n\n```\n\n\n\n\n\n# Build Environment Setup\n\n```shell\n# first, checkout the code\n# second, use conda setup environment \nconda env create -f conda_env.yaml\nconda activate pydui\n# local install \npip install -e .\n```\n\n\n\n\n\n# Refference\n\nhttps://lazka.github.io/pgi-docs/Gtk-3.0/index.html\n\nhttps://valadoc.org/gtk+-3.0/index.htm\n\nhttps://python-gtk-3-tutorial.readthedocs.io/en/latest/index.html',
    'author': 'dzhsurf',
    'author_email': 'dzhsurf@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/dzhsurf/pydui',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
